@@ -327,6 +327,8 @@ gitAnnexDistributor = combineProperties "git-annex distributor, including rsync
 	& endpoint "/srv/web/downloads.kitenet.net/git-annex/autobuild/windows"
 	-- git-annex distribution signing key
 	& Gpg.keyImported (Gpg.GpgKeyId "89C809CB") (User "joey")
+	-- used for building rpms
+	& Apt.installed ["rpm", "createrepo"]
   where
 	endpoint d = combineProperties ("endpoint " ++ d) $ props
 		& File.dirExists d
@@ -902,9 +904,10 @@ alarmClock oncalendar (User user) command = combineProperties "goodmorning timer
 house :: IsContext c => User -> [Host] -> c -> (SshKeyType, Ssh.PubKeyText) -> Property (HasInfo + DebianLike)
 house user hosts ctx sshkey = propertyList "home automation" $ props
 	& Apache.installed
-	& Apt.installed ["python", "python-pymodbus", "rrdtool", "rsync"]
+	& Apt.installed ["libmodbus-dev", "rrdtool", "rsync"]
 	& Git.cloned user "https://git.joeyh.name/git/joey/house.git" d Nothing
 	& Git.cloned user "https://git.joeyh.name/git/reactive-banana-automation.git" (d </> "reactive-banana-automation") Nothing
+	& Git.cloned user "https://git.joeyh.name/git/haskell-libmodbus.git" (d </> "haskell-libmodbus") Nothing
 	& websitesymlink
 	& build
 	& Systemd.enabled setupservicename
@@ -941,6 +944,8 @@ house user hosts ctx sshkey = propertyList "home automation" $ props
 		userScriptProperty (User "joey")
 			[ "cd " ++ d </> "reactive-banana-automation"
 			, "cabal install"
+			, "cd " ++ d </> "haskell-libmodbus"
+			, "cabal install"
 			, "cd " ++ d
 			, "make"
 			]
@@ -1035,11 +1040,11 @@ house user hosts ctx sshkey = propertyList "home automation" $ props
 			createSymbolicLink d "/var/www/html"
 		)
 
-homerouterWifiInterfaceOld :: String
-homerouterWifiInterfaceOld = "wlx00c0ca82eb78" -- thinkpenguin wifi adapter
-
 homerouterWifiInterface :: String
-homerouterWifiInterface = "wlx7cdd90400448" -- small wifi dongle
+homerouterWifiInterface = "wlx9cefd5fcd6f3"
+
+homerouterWifiInterfaceOld :: String
+homerouterWifiInterfaceOld = "wlx7cdd90753b9f"
 
 -- My home router, running hostapd and dnsmasq,
 -- with eth0 connected to a satellite modem, and a fallback ppp connection.
@@ -1083,16 +1088,19 @@ homeRouter = propertyList "home router" $ props
 		]
 		`onChange` Service.restarted "dnsmasq"
 	& ipmasq homerouterWifiInterface
-	-- Used to bring down eth0 when satellite is off, which causes ppp
-	-- to start, but I am not using this currently.
-	& Apt.removed ["netplug"]
 	& Network.static' "eth0" (IPv4 "192.168.1.100")
 		(Just (Network.Gateway (IPv4 "192.168.1.1")))
 		-- When satellite is down, fall back to dialup
 		[ ("pre-up", "poff -a || true")
 		, ("post-down", "pon")
+		-- ethernet autonegotiation with satellite receiver 
+		-- sometimes fails
+		, ("ethernet-autoneg", "off")
+		, ("link-speed", "100")
+		, ("link-duplex", "full")
 		]
 		`requires` Network.cleanInterfacesFile
+		`requires` Apt.installed ["ethtool"]
 	& Apt.installed ["ppp"]
 		`before` File.hasContent "/etc/ppp/peers/provider"
 			[ "user \"joeyh@arczip.com\""
@@ -1230,10 +1238,10 @@ homeNAS = propertyList "home NAS" $ props
 		[ "# let users power control startech hub with uhubctl"
 		, "ATTR{idVendor}==\"" ++ hubvendor ++ "\", ATTR{idProduct}==\"005a\", MODE=\"0666\""
 		]
-	& autoMountDrive "archive-10" (USBHubPort hubvendor 1) (Just "archive-older")
-	& autoMountDrive "archive-11" (USBHubPort hubvendor 2) (Just "archive-old")
-	& autoMountDrive "archive-12" (USBHubPort hubvendor 3) (Just "archive")
-	& autoMountDrive "passport" (USBHubPort hubvendor 4) Nothing
+	& autoMountDrive "archive-10" (USBHubPort hubvendor 1) (Just "archive-oldest")
+	& autoMountDrive "archive-11" (USBHubPort hubvendor 2) (Just "archive-older")
+	& autoMountDrive "archive-12" (USBHubPort hubvendor 3) (Just "archive-old")
+	& autoMountDrive "archive-13" (USBHubPort hubvendor 4) (Just "archive")
 	& Apt.installed ["git-annex", "borgbackup"]
   where
 	hubvendor = "0409"
