@@ -55,7 +55,6 @@ import qualified Propellor.Property.Chroot as Chroot
 import qualified Propellor.Property.Apt as Apt
 import qualified Propellor.Property.File as File
 import Propellor.Property.Systemd.Core
-import Utility.FileMode
 import Utility.Split
 
 import Data.List
@@ -211,7 +210,7 @@ machined = installeddebian `pickOS` assumeinstalled
 		case o of
 			-- Split into separate debian package since systemd 225.
 			(Just (System (Debian _ suite) _))
-				| not (isStable suite) || suite == (Stable "stretch") ->
+				| not (isStable suite) || suite /= (Stable "jessie") ->
 					ensureProperty w $ Apt.installed ["systemd-container"]
 			_ -> noChange
 	assumeinstalled :: Property Linux
@@ -279,16 +278,21 @@ nspawned c@(Container name (Chroot.Chroot loc builder _ _) h) =
 	-- Chroot provisioning is run in systemd-only mode,
 	-- which sets up the chroot and ensures systemd and dbus are
 	-- installed, but does not handle the other properties.
-	chrootprovisioned = Chroot.provisioned' chroot True
+	chrootprovisioned = Chroot.provisioned' chroot True [FilesystemContained]
 
 	-- Use nsenter to enter container and and run propellor to
 	-- finish provisioning.
 	containerprovisioned :: RevertableProperty Linux Linux
 	containerprovisioned =
-		tightenTargets (Chroot.propellChroot chroot (enterContainerProcess c) False)
+		tightenTargets (Chroot.propellChroot chroot (enterContainerProcess c) False containercaps)
 			<!>
 		doNothing
 
+	containercaps = 
+		[ FilesystemContained
+		, HostnameContained
+		]
+
 	chroot = Chroot.Chroot loc builder Chroot.propagateChrootInfo h
 
 -- | Sets up the service files for the container, using the
@@ -387,6 +391,7 @@ mungename = replace "/" "_"
 containerCfg :: String -> RevertableProperty (HasInfo + Linux) (HasInfo + Linux)
 containerCfg p = RevertableProperty (mk True) (mk False)
   where
+	mk :: Bool -> Property (HasInfo + Linux)
 	mk b = tightenTargets $
 		pureInfoProperty desc $
 			mempty { _chrootCfg = SystemdNspawnCfg [(p', b)] }
